@@ -3,13 +3,14 @@ BEGIN {
   $POE::Component::IRC::Plugin::MegaHAL::AUTHORITY = 'cpan:HINRIK';
 }
 BEGIN {
-  $POE::Component::IRC::Plugin::MegaHAL::VERSION = '0.40';
+  $POE::Component::IRC::Plugin::MegaHAL::VERSION = '0.41';
 }
 
 use strict;
 use warnings FATAL => 'all';
 use Carp;
 use Encode qw(decode_utf8 encode_utf8 is_utf8);
+use List::Util qw(first);
 use POE;
 use POE::Component::AI::MegaHAL;
 use POE::Component::IRC::Common qw(l_irc matches_mask_array irc_to_utf8 strip_color strip_formatting);
@@ -130,6 +131,21 @@ sub _megahal_saved {
     return;
 }
 
+sub _ignoring_channel {
+    my ($self, $chan) = @_;
+
+    return if $self->{Own_channel} && $self->_is_own_channel($chan);
+
+    if ($self->{Channels}) {
+        return 1 if !first {
+            my $c = $chan;
+            $c = irc_to_utf8($c) if is_utf8($_);
+            $_ eq $c
+        } @{ $self->{Channels} };
+    }
+    return;
+}
+
 sub _ignoring_user {
     my ($self, $user) = @_;
     
@@ -157,6 +173,7 @@ sub _msg_handler {
     my ($self, $kernel, $type, $user, $chan, $what) = @_[OBJECT, KERNEL, ARG0..$#_];
     my $nick = $self->{irc}->nick_name();
 
+    return if $self->_ignoring_channel($chan);
     return if $self->_ignoring_user($user);
     $what = _normalize_irc($what);
 
@@ -375,6 +392,10 @@ B<'MegaHAL_args'>, a hash reference containing arguments to pass to the
 constructor of a new L<POE::Component::AI::MegaHAL|POE::Component::AI::MegaHAL>
 object.
 
+B<'Channels'>, an array reference of channel names. If this is provided, the
+bot will only listen/respond in the specified channels, rather than all
+channels.
+
 B<'Own_channel'>, a channel where it will reply to all messages, as well as
 greet everyone who joins. The plugin will take care of joining the channel.
 It will part from it when the plugin is removed from the pipeline. Defaults
